==> slices_cli-0.1.56-py3-none-any.whl: slices_cli/util/textual_duration.py <==
"""Helpers for CLI argument str to timedelta."""

import re
from datetime import timedelta

import typer

STR_TO_TIMEDELTA_PATTERN = re.compile(r"^([0-9]+) *([a-z]+)$")


STR_TO_TIMEDELTA_UNITS = [
    "s",
    "second",
    "seconds",
    "min",
    "minute",
    "minutes",
    "h",
    "hour",
    "hours",
    "d",
    "day",
    "days",
    "w",
    "week",
    "weeks",
]
STR_TO_TIMEDELTA_HELP = f"<count:int>[<space>]<unit:str> (where unit one of: {', '.join(STR_TO_TIMEDELTA_UNITS)})"


def str_to_timedelta(duration: str) -> timedelta:
    """Convert a str to a timedelta object.

    This assumes <count:int>[<space>]<unit:str>
    Where unit is one of: s/second/seconds min/minute/minutes h/hour/hours d/day/days w/week/weeks

    Raises ValueError for non convertable str.
    """
    match = STR_TO_TIMEDELTA_PATTERN.match(duration.strip())
    if not match:
        raise ValueError(f"Invalid duration: {duration}")
    count = int(match.group(1))
    unit = match.group(2)
    if unit in ["s", "second", "seconds"]:
        return timedelta(seconds=count)
    if unit in ["m", "minute", "minutes"]:
        return timedelta(minutes=count)
    if unit in ["h", "hour", "hours"]:
        return timedelta(hours=count)
    if unit in ["d", "day", "days"]:
        return timedelta(days=count)
    if unit in ["w", "week", "weeks"]:
        return timedelta(weeks=count)
    raise ValueError(f"Invalid duration unit: {duration}")


def validate_timedelta_str(ctx: typer.Context, param: typer.CallbackParam, value: str) -> str:  # noqa: ARG001
    """Validate a textual timedelta (used for typer arguments)."""
    try:
        str_to_timedelta(value)
    except ValueError as e:
        # raise typer.BadParameter(f"Invalid --{param.name} value {value!r}") from e
        raise typer.BadParameter(f"{value!r}") from e
    return value

==> slices_cli-0.1.61-py3-none-any.whl: slices_cli/util/textual_duration.py <==
"""Helpers for CLI argument str to timedelta."""

import re
from datetime import timedelta

import typer

STR_TO_TIMEDELTA_PATTERN = re.compile(r"^([0-9]+) *([a-z]+)$")


STR_TO_TIMEDELTA_UNITS = [
    "s",
    "second",
    "seconds",
    "min",
    "minute",
    "minutes",
    "h",
    "hour",
    "hours",
    "d",
    "day",
    "days",
    "w",
    "week",
    "weeks",
]
STR_TO_TIMEDELTA_HELP = f"'<number>[optional space]<unit>' (where unit one of: {', '.join(STR_TO_TIMEDELTA_UNITS)})"


def str_to_timedelta(duration: str) -> timedelta:
    """Convert a str to a timedelta object.

    This assumes <count:int>[<space>]<unit:str>
    Where unit is one of: s/second/seconds min/minute/minutes h/hour/hours d/day/days w/week/weeks

    Raises ValueError for non convertable str.
    """
    match = STR_TO_TIMEDELTA_PATTERN.match(duration.strip())
    if not match:
        raise ValueError(f"Invalid duration: {duration}")
    count = int(match.group(1))
    unit = match.group(2)
    if unit in ["s", "second", "seconds"]:
        return timedelta(seconds=count)
    if unit in ["m", "minute", "minutes"]:
        return timedelta(minutes=count)
    if unit in ["h", "hour", "hours"]:
        return timedelta(hours=count)
    if unit in ["d", "day", "days"]:
        return timedelta(days=count)
    if unit in ["w", "week", "weeks"]:
        return timedelta(weeks=count)
    raise ValueError(f"Invalid duration unit: {duration}")


def validate_timedelta_str(ctx: typer.Context, param: typer.CallbackParam, value: str) -> str:  # noqa: ARG001
    """Validate a textual timedelta (used for typer arguments)."""
    try:
        str_to_timedelta(value)
    except ValueError as e:
        # raise typer.BadParameter(f"Invalid --{param.name} value {value!r}") from e
        raise typer.BadParameter(f"{value!r}") from e
    return value
